@@ -23,7 +23,7 @@ const (
 	SYMBOL_SIZE_MISMATCH_TAG                        = "symbol-size-mismatch"
 	MISSING_SYMBOL_VERSION_INFORMATION_TAG          = "missing-symbol-version-information"
 	LIBRARY_NOT_FOUND_TAG                           = "library-not-found"
-	INCOMPATIBLE_LICENSES_TAG                       = "incompatible-licenses"
+	INCOMPATIBLE_LICENSES_TAG                       = "incompatible-licenses" // obsolete
 	LDD_FAILURE_TAG                                 = "ldd-failure"
 )
 
@@ -38,13 +38,12 @@ var elfTags = []string{
 }
 
 type elfErr struct {
-	tag              string
-	pkg              string
-	path             string
-	symbol           string
-	lib              string
-	licenseConflicts string
-	err              error
+	tag    string
+	pkg    string
+	path   string
+	symbol string
+	lib    string
+	err    error
 }
 
 func (c elfErr) Error() string {
@@ -64,8 +63,6 @@ func (c elfErr) Error() string {
 		return fmt.Sprintf("%s: %s %s => %s", c.pkg, c.tag, c.path, c.lib)
 	case LIBRARY_NOT_FOUND_TAG:
 		return fmt.Sprintf("%s: %s %s => %s", c.pkg, c.tag, c.path, c.lib)
-	case INCOMPATIBLE_LICENSES_TAG:
-		return fmt.Sprintf("%s: %s %s %s", c.pkg, c.tag, c.path, c.licenseConflicts)
 	default:
 		log.Fatal("Invalid elf error tag: ", c.tag)
 		return "" // will never get here
@@ -178,15 +175,7 @@ func (cc elfChecker) check(pkg2files map[string][]string) []elfErr {
 		"): no version information available [(]required by (" + nonSpaceToken + ")[)]$")
 	missingLibRE := regexp.MustCompile("^[\t ]*(" + nonSpaceToken + ") => not found$")
 	libthreadRE := regexp.MustCompile(`libthread_db\.so(\.[0-9.]+)?$`)
-	soNamePathRE := regexp.MustCompile("(" + nonSpaceToken + ") => (" + nonSpaceToken + ") [(]0x[0-9a-f]+[)]$")
 
-	dep5Licenses := loadPkgLicenses(mapStrKeys(pkg2files))
-	type conflictKey struct {
-		pkg            string
-		depends        map[string]bool
-		soNameLicenses string
-	}
-	licenseConflicts := make(map[string]conflictKey)
 	for path, pkg := range path2pkg {
 		if is, err := isDir(path); err == nil && is {
 			continue
@@ -198,16 +187,6 @@ func (cc elfChecker) check(pkg2files map[string][]string) []elfErr {
 		if e := strings.TrimSpace(strings.Join(output, " ")); e == "statically linked" || e == "not a dynamic executable" {
 			continue
 		}
-		depends := make(map[string]bool)
-		var soNameLicenses []soNameLicense
-		licenseIDproduct := licenseID(-1)
-		license, ok := dep5Licenses[pkg]
-		if ok {
-			licenseIDproduct = license.id()
-			soNameLicenses = []soNameLicense{
-				{soName: "", license: license},
-			}
-		}
 
 		if err != nil {
 			if !cc.tagsToEmit[LDD_FAILURE_TAG] {
@@ -331,92 +310,9 @@ func (cc elfChecker) check(pkg2files map[string][]string) []elfErr {
 				})
 				continue
 			}
-			if m := soNamePathRE.FindStringSubmatch(line); len(m) == 3 {
-				if !cc.tagsToEmit[INCOMPATIBLE_LICENSES_TAG] {
-					continue
-				}
-				soName, soPath := m[1], m[2]
-				realSoPath := realPath(soPath)
-				if dirsToCheck[filepath.Dir(realSoPath)] {
-					depends[realSoPath] = true
-				}
-				license := soname2license[soName]
-				if license.undefined() {
-					// This may yield false positives as
-					// soname2license rots.
-					// TODO: add a tunable to optionally log
-					// unknown licenses.
-					continue
-				}
-				newLincenseIDproduct := licenseIDproduct & license.id()
-				if licenseIDproduct != newLincenseIDproduct {
-					soNameLicenses = append(soNameLicenses,
-						soNameLicense{
-							soName:  soName,
-							license: license,
-						},
-					)
-				}
-				licenseIDproduct = newLincenseIDproduct
-				if licenseIDproduct == 0 {
-					// Don't emit incompatible-licenses tag yet, because
-					// the conflict might have been caused by one of the
-					// dependencies.
-					var ss []string
-					for _, lic := range soNameLicenses {
-						ss = append(ss, lic.String())
-					}
-					licenseConflicts[path] = conflictKey{
-						pkg,
-						depends,
-						strings.Join(ss, " + "),
-					}
-
-				}
-
-			}
 		}
 	}
 
-	dependencyLicenses := make(map[string]licenseID)
-	for _, soPaths := range licenseConflicts {
-		for soPath := range soPaths.depends {
-			dependencyLicenses[soPath] = -1
-		}
-	}
-	for path := range dependencyLicenses {
-		lines, err := runCommand([]string{"/bin/ldd", path})
-		if err != nil {
-			log.Fatal("ldd: ", err)
-		}
-
-		for _, line := range lines {
-			if m := soNamePathRE.FindStringSubmatch(line); len(m) == 3 {
-				soName := m[1]
-				license := soname2license[soName]
-				if license == unknownLicense {
-					continue
-				}
-				dependencyLicenses[path] &= license.id()
-			}
-
-		}
-	}
-file:
-	for path, conflictKey := range licenseConflicts {
-		for soPath := range conflictKey.depends {
-			if dependencyLicenses[soPath] == 0 {
-				continue file
-			}
-		}
-		tags = append(tags, elfErr{
-			tag:              INCOMPATIBLE_LICENSES_TAG,
-			pkg:              conflictKey.pkg,
-			path:             path,
-			licenseConflicts: conflictKey.soNameLicenses,
-		})
-	}
-
 	return tags
 }
 
